<?php
/* Copyright (C) 2007-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2020      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	    \file       htdocs/hidemargin/admin/setup.php
 *		\ingroup    hidemargin
 *		\brief      Page to setup hidemargin module
 */

// Change this following line to use the correct relative path (../, ../../, etc)
$res = 0;
if (!$res && file_exists("../../main.inc.php"))     $res = @include '../../main.inc.php';			// to work if your module directory is into a subdir of root htdocs directory
if (!$res && file_exists("../../../main.inc.php"))  $res = @include '../../../main.inc.php';		// to work if your module directory is into a subdir of root htdocs directory
if (!$res) die("Include of main fails");
require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
dol_include_once('/hidemargin/lib/hidemargin.lib.php');

$langs->load("admin");
$langs->load("hidemargin@hidemargin");
$langs->load("opendsi@hidemargin");

if (!$user->admin) accessforbidden();

$action = GETPOST('action','alpha');


$error = 0;
$errors = array();
/*
 *	Actions
 */

if (preg_match('/set_(.*)/',$action,$reg)) {
    $code = $reg[1];
    $value = (GETPOST($code) ? GETPOST($code) : 1);
    if (dolibarr_set_const($db, $code, $value, 'chaine', 0, '', $conf->entity) > 0) {
        header('Location: ' . $_SERVER["PHP_SELF"]);
        exit();
    } else {
        $error++;
        $errors[] = $db->lasterror();
    }
} elseif (preg_match('/del_(.*)/',$action,$reg)) {
    $code = $reg[1];
    if (dolibarr_del_const($db, $code, $conf->entity) > 0) {
        header('Location: ' . $_SERVER["PHP_SELF"]);
        exit();
    } else {
        $error++;
        $errors[] = $db->lasterror();
    }
} elseif ($action == 'set') {

}

if ($action != '') {
    if (!$error) {
        setEventMessage($langs->trans('SetupSaved'));
    } else {
        setEventMessages('', $errors, 'errors');
    }
}

/*
 *	View
 */


$wikihelp='EN:HideMargin_En|FR:HideMargin_Fr|ES:HideMargin_Es';
llxHeader('', $langs->trans("HideMarginSetup"), $wikihelp);

$linkback = '<a href="'.DOL_URL_ROOT.'/admin/modules.php">'.$langs->trans("BackToModuleList").'</a>';
print load_fiche_titre($langs->trans("HideMarginSetup"),$linkback,'title_setup');
print "<br>\n";

$head = hidemargin_admin_prepare_head();

print dol_get_fiche_head($head, 'settings', $langs->trans("Module163042Name"), 0, 'opendsi@hidemargin');

print '<br>';
print '<form method="post" action="'.$_SERVER["PHP_SELF"].'">';
print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
print '<input type="hidden" name="action" value="set">';

$var=true;

print '<table class="noborder" width="100%">';
print '<tr class="liste_titre">';
print '<td>'.$langs->trans("Parameters").'</td>'."\n";
print '<td align="center">&nbsp;</td>'."\n";
print '<td align="right">'.$langs->trans("Value").'</td>'."\n";
print "</tr>\n";

// HIDEMARGIN_PROPAL_ENABLED
$var = !$var;
print '<tr ' . $bc[$var] . '>' . "\n";
print '<td>' . $langs->trans('HideMarginPropalEnabledName') . '</td>' . "\n";
print '<td>' . $langs->trans('HideMarginPropalEnabledDesc') . '</td>' . "\n";
print '<td align="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('HIDEMARGIN_PROPAL_ENABLED');
} else {
    if (empty($conf->global->HIDEMARGIN_PROPAL_ENABLED)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_HIDEMARGIN_PROPAL_ENABLED">' . img_picto($langs->trans('Disabled'), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_HIDEMARGIN_PROPAL_ENABLED">' . img_picto($langs->trans('Enabled'), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// HIDEMARGIN_ORDER_ENABLED
$var = !$var;
print '<tr ' . $bc[$var] . '>' . "\n";
print '<td>' . $langs->trans('HideMarginOrderEnabledName') . '</td>' . "\n";
print '<td>' . $langs->trans('HideMarginOrderEnabledDesc') . '</td>' . "\n";
print '<td align="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('HIDEMARGIN_ORDER_ENABLED');
} else {
    if (empty($conf->global->HIDEMARGIN_ORDER_ENABLED)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_HIDEMARGIN_ORDER_ENABLED">' . img_picto($langs->trans('Disabled'), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_HIDEMARGIN_ORDER_ENABLED">' . img_picto($langs->trans('Enabled'), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

// HIDEMARGIN_INVOICE_ENABLED
$var = !$var;
print '<tr ' . $bc[$var] . '>' . "\n";
print '<td>' . $langs->trans('HideMarginInvoiceEnabledName') . '</td>' . "\n";
print '<td>' . $langs->trans('HideMarginInvoiceEnabledDesc') . '</td>' . "\n";
print '<td align="right">' . "\n";
if (!empty($conf->use_javascript_ajax)) {
    print ajax_constantonoff('HIDEMARGIN_INVOICE_ENABLED');
} else {
    if (empty($conf->global->HIDEMARGIN_INVOICE_ENABLED)) {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=set_HIDEMARGIN_INVOICE_ENABLED">' . img_picto($langs->trans('Disabled'), 'switch_off') . '</a>';
    } else {
        print '<a href="' . $_SERVER['PHP_SELF'] . '?action=del_HIDEMARGIN_INVOICE_ENABLED">' . img_picto($langs->trans('Enabled'), 'switch_on') . '</a>';
    }
}
print '</td></tr>' . "\n";

print '</table>';

dol_fiche_end();

print '<br>';
//print '<div align="center">';
//print '<input type="submit" class="button" value="'.$langs->trans("Modify").'">';
//print '</div>';

print '</form>';

llxFooter();

$db->close();
