<?php
/* Copyright (C) 2020      Open-DSI             <support@open-dsi.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

require_once DOL_DOCUMENT_ROOT.'/core/lib/functions.lib.php';
dol_include_once('/hidemargin/lib/hidemargin.lib.php');

/**
 *  \file       htdocs/hidemargin/class/actions_hidemargin.class.php
 *  \ingroup    hidemargin
 *  \brief      File for hooks
 */

class ActionsHideMargin
{
    /**
     * Overloading the doActions function : replacing the parent's function with the one below
     *
     * @param   array()         $parameters     Hook metadatas (context, etc...)
     * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param   string          &$action        Current action (if set). Generally create or edit or null
     * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    function doActions($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $langs, $user;

        $contexts = explode(':', $parameters['context']);

        if ((!empty($conf->global->HIDEMARGIN_PROPAL_ENABLED) && in_array('propalcard', $contexts))
            || (!empty($conf->global->HIDEMARGIN_ORDER_ENABLED) && in_array('ordercard', $contexts) )
            || (!empty($conf->global->HIDEMARGIN_INVOICE_ENABLED) && in_array('invoicecard', $contexts))) {

            $langs->load('hidemargin@hidemargin');

            if ($action == 'hidemargin_hide') {
                $_SESSION['hidemargin_margin_show'] = false;
            }

            if ($action == 'hidemargin_show' && ($user->rights->hidemargin->read_columns || $user->rights->hidemargin->lire_tableau)) {
                $_SESSION['hidemargin_margin_show'] = true;
            }
        }

        return 0;
    }

    /**
     * Overloading the addMoreActionsButtons function : replacing the parent's function with the one below
     *
     * @param   array()         $parameters     Hook metadatas (context, etc...)
     * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param   string          &$action        Current action (if set). Generally create or edit or null
     * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    function addMoreActionsButtons($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $langs, $user;

        $contexts = explode(':', $parameters['context']);

        if ((!empty($conf->global->HIDEMARGIN_PROPAL_ENABLED) && in_array('propalcard', $contexts))
            || (!empty($conf->global->HIDEMARGIN_ORDER_ENABLED) && in_array('ordercard', $contexts))
            || (!empty($conf->global->HIDEMARGIN_INVOICE_ENABLED) && in_array('invoicecard', $contexts))
        ) {

            $langs->load('hidemargin@hidemargin');

            $marginShow = !empty($_SESSION['hidemargin_margin_show']) ? true : false;

            if (!empty($conf->global->MAIN_MODULE_MARGIN)) {

                if ($marginShow) {
                    print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&amp;action=hidemargin_hide">' . $langs->trans('HideMarginHide') . '</a></div>';
                } else {
                    if ($user->rights->hidemargin->read_table || $user->rights->hidemargin->read_columns) {
                        print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&amp;action=hidemargin_show">' . $langs->trans('HideMarginShow') . '</a></div>';
                    }
                }
            }
        }

        return 0;
    }

    /**
     * Overloading the formObjectOptions function : replacing the parent's function with the one below
     *
     * @param   array()         $parameters     Hook metadatas (context, etc...)
     * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param   string          &$action        Current action (if set). Generally create or edit or null
     * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    function formObjectOptions($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $user;

        $contexts = explode(':', $parameters['context']);

        if ((!empty($conf->global->HIDEMARGIN_PROPAL_ENABLED) && in_array('propalcard', $contexts))
            || (!empty($conf->global->HIDEMARGIN_ORDER_ENABLED) && in_array('ordercard', $contexts) )
            || (!empty($conf->global->HIDEMARGIN_INVOICE_ENABLED) && in_array('invoicecard', $contexts))) {
            $marginShow = !empty($_SESSION['hidemargin_margin_show']) ? true : false;

            $affCol = false;
            $affTab = false;

            if ($marginShow) {
                $affCol = $user->rights->hidemargin->read_columns ? true : false;
                $affTab = $user->rights->hidemargin->read_table ? true : false;
            }

            if (!$affCol || !$affTab) {
                print '<script type="text/javascript">' . "\r\n";
                print '$(document).ready(function() {' . "\r\n";

                if (!$affTab) {
                    print '		$(".margintable").hide();' . "\r\n";
                }
                if (!$affCol) {
                    print '		$(".margininfos").hide();' . "\r\n";
                    print '		$("#fournprice_predef").hide();' . "\r\n";
                    print '		$("#buying_price").hide();' . "\r\n";

                    //print '		$("#addproduct").append(\'<input type="hidden" id="fournprice_predef2" name="fournprice_predef" value="costprice" />\');' . "\r\n";
                    //print '		$("#addproduct").append(\'<input type="hidden" id="buying_price2" name="buying_price" value="" />\');' . "\r\n";

                    print '		$("#idprod").change(function() {' . "\r\n";
                    print '			$.post(\'' . DOL_URL_ROOT . '/fourn/ajax/getSupplierPrices.php?bestpricefirst=1\', { \'idprod\': $(this).val() }, function(data) {' . "\r\n";
                    print '				if (data && data.length > 0)' . "\r\n";
                    print '				{' . "\r\n";
                    print '					var defaultprice = \'\';' . "\r\n";

                    print '					$(data).each(function() {' . "\r\n";
                    print '						if (this.id == \'costprice\')' . "\r\n";
                    print '						{' . "\r\n";
                    print '					  		if (this.price > 0) { defaultprice = this.price; }' . "\r\n";
                    print '						}' . "\r\n";
                    print '					});' . "\r\n";
                    print '					$("#buying_price").val(defaultprice);' . "\r\n";
                    print '				}' . "\r\n";
                    print '			},\'json\');' . "\r\n";
                    print '		});' . "\r\n";
                }

                print '});' . "\r\n";
                print '</script>' . "\r\n";
            }
        }

        return 0;
    }
}
