<?php
/* Copyright (C) 2012-2013	Christophe Battarel	<christophe.battarel@altairis.fr>
 * Copyright (C) 2014		Ferran Marcet		<fmarcet@2byte.es>
 * Copyright (C) 2015       Marcos García       <marcosgdf@gmail.com>
 * Copyright (C) 2016       Florian Henry       <florian.henry@open-concept.pro>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * \file htdocs/margin/checkMargins.php
 * \ingroup margin
 * \brief Check margins
 */
// Change this following line to use the correct relative path (../, ../../, etc)
$res=0;
if (! $res && file_exists("../main.inc.php")) $res=@include '../main.inc.php';					// to work if your module directory is into dolibarr root htdocs directory
if (! $res && file_exists("../../main.inc.php")) $res=@include '../../main.inc.php';			// to work if your module directory is into a subdir of root htdocs directory
if (! $res && file_exists("../../../dolibarr/htdocs/main.inc.php")) $res=@include '../../../dolibarr/htdocs/main.inc.php';     // Used on dev env only
if (! $res && file_exists("../../../../dolibarr/htdocs/main.inc.php")) $res=@include '../../../../dolibarr/htdocs/main.inc.php';   // Used on dev env only
if (! $res) die("Include of main fails");

require_once DOL_DOCUMENT_ROOT . '/core/lib/company.lib.php';
require_once DOL_DOCUMENT_ROOT . '/core/lib/invoice.lib.php';
require_once DOL_DOCUMENT_ROOT . '/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT . '/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT . '/margin/lib/margins.lib.php';

// Load translation files required by the page
$langs->loadLangs(array('companies', 'bills', 'products', 'margins'));
// Security check
$result=restrictedArea($user, 'margins');
if (!$user->hasRight('hidemargin', 'show_invoice_tab')) {
	accessForbidden();
}
// Both test are required to be compatible with all browsers
if (GETPOST("button_search_x") || GETPOST("button_search")) {
    $action = 'search';
} elseif (GETPOST("button_updatemagins_x") || GETPOST("button_updatemagins")) {
    $action = 'update';
}
$id = (GETPOST('id', 'int') ? GETPOST('id', 'int') : GETPOST('facid', 'int'));

/*
 * Actions
*/
$parameters=array();
$reshook=$hookmanager->executeHooks('doActions', $parameters, $object, $action);    // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');

if (empty($reshook))
{
    // Selection of new fields
    include DOL_DOCUMENT_ROOT.'/core/actions_changeselectedfields.inc.php';

	if ($user->rights->margins->creer) {

		if ($action == 'update') {
			$datapost = $_POST;

			foreach ($datapost as $key => $value) {
				if (strpos($key, 'buyingprice_') !== false) {
					$tmp_array = explode('_', $key);
					if (count($tmp_array) > 0) {
						$invoicedet_id = $tmp_array[1];
						if (! empty($invoicedet_id)) {
							$sql = 'UPDATE ' . MAIN_DB_PREFIX . 'facturedet';
							$sql .= ' SET buy_price_ht=\'' . price2num($value) . '\'';
							$sql .= ' WHERE rowid=' . $invoicedet_id;
							$result = $db->query($sql);
							if (!$result) {
								setEventMessages($db->lasterror, null, 'errors');
							} else {
                                header('Location: '.DOL_URL_ROOT.'/compta/facture/card.php?id=' . $id);
                            }
						}
					}
				}
			}
		}
	}

    // Purge search criteria
    if (GETPOST('button_removefilter_x', 'alpha') || GETPOST('button_removefilter.x', 'alpha') || GETPOST('button_removefilter', 'alpha')) // All tests are required to be compatible with all browsers
    {
        $search_ref='';
        $search_array_options=array();
    }
}


/*
 * View
*/

$userstatic = new User($db);
$companystatic = new Societe($db);
$invoicestatic = new Facture($db);
$productstatic = new Product($db);
$form = new Form($db);

$title = $langs->trans("Margins");

llxHeader('', $title);

$object = new Facture($db);
$extrafields = new ExtraFields($db);


// Load object
if ($id > 0 || ! empty($ref)) {
	$ret = $object->fetch($id, $ref, '', $conf->global->INVOICE_USE_SITUATION);
}

$head = facture_prepare_head($object);
print dol_get_fiche_head($head, 'HideMarginInvoiceMargeTab', $title, -1, 'bill');

print '<form method="post" name="sel" action="' . $_SERVER['PHP_SELF'] . '?id='. $object->id.'">';
print '<input type="hidden" name="token" value="'.newToken().'">';
print '<table class="border" width="100%">';
$arrayfields=array();
$sql = "SELECT";
$sql .= " f.ref, f.rowid as invoiceid, d.rowid as invoicedetid, d.buy_price_ht, d.total_ht, d.subprice, d.label, d.description , d.qty";
$sql .= " ,d.fk_product";
$sql .= " FROM " . MAIN_DB_PREFIX . "facture as f ";
$sql .= " INNER JOIN " . MAIN_DB_PREFIX . "facturedet as d  ON d.fk_facture = f.rowid";
$sql .= " LEFT JOIN " . MAIN_DB_PREFIX . "product as p ON d.fk_product = p.rowid";
$sql .= " WHERE f.entity IN (" . getEntity('invoice') . ") AND f.rowid = ".$object->id;
$sql .= " AND d.buy_price_ht IS NOT NULL";

$result = $db->query($sql);
if ($result) {
	$num = $db->num_rows($result);
	print '<br>';
	print_barre_liste($langs->trans("MarginDetails"), $page, $_SERVER["PHP_SELF"] . '?id='. $object->id, $param, $sortfield, $sortorder, '', $num, $nbtotalofrecords, '', 0, '', '', $limit);

	if ($conf->global->MARGIN_TYPE == "1")
	    $labelcostprice='BuyingPrice';
	else   // value is 'costprice' or 'pmp'
	    $labelcostprice='CostPrice';


	$varpage=empty($contextpage)?$_SERVER["PHP_SELF"]:$contextpage;
	//$selectedfields=$form->multiSelectArrayWithCheckbox('selectedfields', $arrayfields, $varpage);	// This also change content of $arrayfields
	//if ($massactionbutton) $selectedfields.=$form->showCheckAddButtons('checkforselect', 1);
	$selectedfields='';

    print '<div class="div-table-responsive">';
    print '<table class="tagtable liste">'."\n";

	print '<tr class="liste_titre liste_titre_search">';
	print '<td></td>';
	print '<td></td>';
	print '<td></td>';
	print '<td></td>';
	print '<td></td>';
	print '<td></td>';
    print '<td class="liste_titre" align="middle">';
    print '</td>';
	print "</tr>\n";
	print '<tr class="liste_titre">';

    print_liste_field_titre("Ref", $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, '', $sortfield, $sortorder);
    print_liste_field_titre("Description", $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, 'width=20%', $sortfield, $sortorder);
    print_liste_field_titre("UnitPriceHT", $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, 'align="right"', $sortfield, $sortorder);
	print_liste_field_titre($labelcostprice, $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, 'align="right"', $sortfield, $sortorder);
	print_liste_field_titre("Qty", $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, 'align="right"', $sortfield, $sortorder);
	print_liste_field_titre("AmountTTC", $_SERVER["PHP_SELF"] . '?id='.$object->id, "", "", $param, 'align="right"', $sortfield, $sortorder);
	print_liste_field_titre($selectedfields, $_SERVER["PHP_SELF"] . '?id='.$object->id, "", '', $param, 'align="center"', $sortfield, $sortorder, 'maxwidthsearch ');
	print "</tr>\n";

    $i=0;
	while ($i < $num)
	{
	    $objp = $db->fetch_object($result);
		print '<tr class="oddeven">';
		print '<td>';
		$result_inner = $invoicestatic->fetch($objp->invoiceid);
		if ($result_inner < 0) {
			setEventMessages($invoicestatic->error, null, 'errors');
		} else {
			print $invoicestatic->getNomUrl(1);
		}
		print '</td>';
		print '<td>';
		if (! empty($objp->fk_product)) {
			$result_inner = $productstatic->fetch($objp->fk_product);
			if ($result_inner < 0) {
				setEventMessages($productstatic->error, null, 'errors');
			} else {
				print $productstatic->getNomUrl(1);
			}
		} else {
			print $objp->label;
			print '&nbsp;';
			print $objp->description;
		}
		print '</td>';
		print '<td class="right">';
		print price($objp->subprice);
		print '</td>';
		print '<td class="right">';
		print '<input type="text" name="buyingprice_' . $objp->invoicedetid . '" id="buyingprice_' . $objp->invoicedetid . '" size="6" value="' . price($objp->buy_price_ht) . '" class="right flat">';
		print '</td>';
		print '<td class="right">';
		print $objp->qty;
		print '</td>';
		print '<td class="right">';
		print price($objp->total_ht);
		print '</td>';
		print '<td></td>';
		print "</tr>\n";
		$i ++;
	}
	print "</table>";
	print "</div>";
} else {
	dol_print_error($db);
}

print '<div class="center">' . "\n";
print '<input type="submit" class="button" name="button_updatemagins" id="button_updatemagins" value="' . $langs->trans("Update") . '">';
print '</div>';
print '</form>';
print dol_get_fiche_end();
$db->free($result);

// End of page
llxFooter();
$db->close();
